@@ -29,6 +29,7 @@ installPackages+=(ninja-build)
 installPackages+=(pcre2-devel)
 installPackages+=(double-conversion-devel)
 installPackages+=(zstd)
+installPackages+=(libzstd-devel)
 # EGL support
 # mesa-libEGL-devel need to use older version than 22.1.5-2.el9 which cause Xorg to crash
 #installPackages+=(mesa-libEGL-devel-21.3.4-2.el9)
@@ -93,7 +94,7 @@ installPackages+=(python3-html5lib)
 installPackages+=(libstdc++-static)
 installPackages+=(mesa-libgbm-devel-21.3.4-2.el9.x86_64)
 # For Android builds
-installPackages+=(java-11-openjdk-devel)
+installPackages+=(java-17-openjdk-devel-17.0.9.0.9)
 # For receiving shasum
 installPackages+=(perl-Digest-SHA)
 # INTEGRITY requirements
