@@ -1,5 +1,6 @@
 #!/usr/bin/env bash
 # Copyright (C) 2022 The Qt Company Ltd.
+# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 set -ex
 
@@ -36,11 +37,13 @@ sudo zypper -nq install xcb-util-devel xcb-util-image-devel xcb-util-keysyms-dev
 sudo zypper -nq install libicu-devel
 
 # qtwebengine
-# Removing nodejs12 as it's not available and testing with common nodejs 18.16.0
 sudo zypper -nq install alsa-devel dbus-1-devel libxkbfile-devel \
          libXcomposite-devel libXcursor-devel libXrandr-devel libXtst-devel \
-         mozilla-nspr-devel mozilla-nss-devel glproto-devel \
-         libxshmfence-devel libXdamage-devel
+         mozilla-nspr-devel mozilla-nss-devel nodejs12 glproto-devel \
+         libxshmfence-devel libXdamage-devel libdrm-devel libgbm-devel
+
+# qtwebengine, qtmultimedia+ffmpeg
+sudo zypper -nq install libva-devel
 
 # qtwebkit
 sudo zypper -nq install libxml2-devel libxslt-devel
